<?php
/**
 * @file
 * Logic for warden output
 */

require_once ('warden_encryption.inc');

/**
 * Return JSON formatted module information.
 */
function warden_status_page() {
  global $base_url;

  $drupal_modules = module_list();
  $system_themes = list_themes(TRUE);

  $system_modules = array();
  foreach ($drupal_modules as $name) {
    $path = drupal_get_path('module', $name) . '/' . $name . '.info';
    $info = drupal_parse_info_file($path);
    $system_modules[$info['project']] = $info;
  }

  // Needless initialisation, but hey.
  $res = array(
    "core" => array(),
    "contrib" => array(),
    "custom" => "disabled",
  );

  $res['system'] = $system_modules;

  foreach ($system_modules as $module) {
    if (isset($module['project']) && $module['project'] != "drupal") {
      $res['contrib'][$module['project']] = array("version" => $module['version']);
    }
  }

  $res['core']['drupal'] = array("version" => VERSION);

  foreach ($system_themes as $theme) {
    if (isset($theme->info['project']) && $theme->info['project'] == "drupal")
      continue;

    if (isset($theme->info['version']) && isset($theme->info['project']))
      $res['contrib'][$theme->info['project']] = array("version" => $theme->info['version']);
  }


  // Site name.
  $res['site_name'] = variable_get('site_name', $base_url);

  try {
    $encrypted_message = warden_get_encryption()->encrypt($res);

    _warden_json_output(array(
      'data' => $encrypted_message,
    ));
  }
  catch (Exception $e) {
    _warden_json_output(array('error' => 'Internal fault'));
  }

}

/**
 * Encode a variable to JSON and send as output to browser.
 */
function _warden_json_output($data) {
  header('Content-Type: application/json');
  echo json_encode($data);
  exit;
}
